Learn R Programming

FactEff (version 1.0)

autogenerate_design: Autogenerate a blocked factorial design for given number of factors, factor levels, block size and replications

Description

Autogenerate a blocked factorial design for given number of factors, factor levels, block size and replications

Usage

autogenerate_design(n_factors, factor_levels, block_size, replications)

Value

Returns a blocked factorial design with columns representing blocks and entries representing treatment combinations

Arguments

n_factors

a positive integer, denoting number of factors

factor_levels

a numeric vector with positive entries with length same as n_factors, elements denoting levels of factors

block_size

a positive integer, denoting block size

replications

a positive integer, denoting number of replications

Examples

Run this code
autogenerate_design(2,c(3,4),3,2)

Run the code above in your browser using DataLab