powered by
Autogenerate a blocked factorial design for given number of factors, factor levels, block size and replications
autogenerate_design(n_factors, factor_levels, block_size, replications)
Returns a blocked factorial design with columns representing blocks and entries representing treatment combinations
a positive integer, denoting number of factors
a numeric vector with positive entries with length same as n_factors, elements denoting levels of factors
a positive integer, denoting block size
a positive integer, denoting number of replications
autogenerate_design(2,c(3,4),3,2)
Run the code above in your browser using DataLab